@@ -39,31 +39,34 @@
 #' ci(df, method = "ETI", ci = c(.80, .89, .95))
 #' ci(df, method = "HDI", ci = c(.80, .89, .95))
 #'
-#' library(rstanarm)
-#' model <- stan_glm(mpg ~ wt, data = mtcars, chains = 2, iter = 200, refresh = 0)
-#' ci(model, method = "ETI", ci = c(.80, .89))
-#' ci(model, method = "HDI", ci = c(.80, .89))
-#' ci(model, method = "SI")
-#'
 #' \dontrun{
-#' library(brms)
-#' model <- brms::brm(mpg ~ wt + cyl, data = mtcars)
-#' ci(model, method = "ETI")
-#' ci(model, method = "HDI")
-#' ci(model, method = "SI")
-#'
-#' library(BayesFactor)
-#' bf <- ttestBF(x = rnorm(100, 1, 1))
-#' ci(bf, method = "ETI")
-#' ci(bf, method = "HDI")
-#'
-#' library(emmeans)
-#' model <- emtrends(model, ~1, "wt")
-#' ci(model, method = "ETI")
-#' ci(model, method = "HDI")
-#' ci(model, method = "SI")
+#' if (require("rstanarm")) {
+#'   model <- stan_glm(mpg ~ wt, data = mtcars, chains = 2, iter = 200, refresh = 0)
+#'   ci(model, method = "ETI", ci = c(.80, .89))
+#'   ci(model, method = "HDI", ci = c(.80, .89))
+#'   ci(model, method = "SI")
 #' }
 #'
+#' if (require("brms")) {
+#'   model <- brms::brm(mpg ~ wt + cyl, data = mtcars)
+#'   ci(model, method = "ETI")
+#'   ci(model, method = "HDI")
+#'   ci(model, method = "SI")
+#' }
+#'
+#' if (require("BayesFactor")) {
+#'   bf <- ttestBF(x = rnorm(100, 1, 1))
+#'   ci(bf, method = "ETI")
+#'   ci(bf, method = "HDI")
+#' }
+#'
+#' if (require("emmeans")) {
+#'   model <- emtrends(model, ~1, "wt")
+#'   ci(model, method = "ETI")
+#'   ci(model, method = "HDI")
+#'   ci(model, method = "SI")
+#' }
+#' }
 #' @export
 ci <- function(x, ...) {
   UseMethod("ci")
@@ -155,3 +158,9 @@ ci.MCMCglmm <- function(x, ci = .89, method = "ETI", verbose = TRUE, ...) {
 ci.mcmc <- function(x, ci = .89, method = "ETI", verbose = TRUE, ...) {
   ci(as.data.frame(x), ci = ci, method = method, verbose = verbose, ...)
 }
+
+
+#' @export
+ci.bcplm <- function(x, ci = .89, method = "ETI", verbose = TRUE, ...) {
+  ci(insight::get_parameters(x), ci = ci, method = method, verbose = verbose, ...)
+}
