@@ -325,6 +325,58 @@ describe_posterior.double <- describe_posterior.numeric
 #' @export
 describe_posterior.data.frame <- describe_posterior.numeric
 
+#' @export
+describe_posterior.effectsize_std_params <- function(posteriors, centrality = "median", dispersion = FALSE, ci = 0.89, ci_method = "hdi", test = c("p_direction", "rope"), rope_range = "default", rope_ci = 0.89, bf_prior = NULL, BF = 1, ...){
+
+  class(posteriors) <- "data.frame"
+
+  no_unique <- sapply(posteriors, function(col) {
+    length(unique(col)) == 1
+  })
+
+  if (any(no_unique)) {
+    no_unique <- which(no_unique)
+
+    out <- describe_posterior.data.frame(
+      posteriors[,-no_unique],
+      centrality = centrality,
+      dispersion = dispersion,
+      ci = ci,
+      ci_method = ci_method,
+      test = test,
+      rope_range = rope_range,
+      rope_ci = rope_ci,
+      bf_prior = bf_prior,
+      BF = BF,
+      ...
+    )
+
+    out_int <- data.frame(Parameter = colnames(posteriors)[no_unique])
+    col_diff <- setdiff(colnames(out), colnames(out_int))
+    out_int[, col_diff] <- NA
+    out <- rbind(out_int, out)
+
+    out <- out[order(match(out$Parameter,colnames(posteriors))),]
+
+    return(out)
+  }
+
+  describe_posterior.data.frame(
+    posteriors,
+    centrality = centrality,
+    dispersion = dispersion,
+    ci = ci,
+    ci_method = ci_method,
+    test = test,
+    rope_range = rope_range,
+    rope_ci = rope_ci,
+    bf_prior = bf_prior,
+    BF = BF,
+    ...
+  )
+
+}
+
 
 #' @export
 describe_posterior.sim.merMod <- describe_posterior.numeric
