@@ -13,6 +13,7 @@
 #'   }
 #'
 #' @examples
+#' \dontrun{
 #' library(bayestestR)
 #'
 #' posterior <- rnorm(10000)
@@ -20,7 +21,7 @@
 #'
 #' plot(density(posterior))
 #' abline(v = map_estimate(posterior), col = "red")
-#' \dontrun{
+#'
 #' library(rstanarm)
 #' model <- rstanarm::stan_glm(mpg ~ wt + cyl, data = mtcars)
 #' map_estimate(model)
@@ -39,18 +40,6 @@ map_estimate <- function(x, precision = 2^10, method = "kernel", ...) {
 
 
 
-#' @export
-print.map_estimate <- function(x, ...) {
-  if (inherits(x, "data.frame")) {
-    print.data.frame(x)
-  } else {
-    cat(sprintf("MAP = %.2f", x))
-  }
-}
-
-
-
-
 
 #' @rdname map_estimate
 #' @export
