@@ -1,6 +1,7 @@
 #' @importFrom insight print_color
 #' @export
 print.rope <- function(x, digits = 2, ...) {
+  orig_x <- x
   insight::print_color(sprintf(
     "# Proportion%s of samples inside the ROPE [%.*f, %.*f]:\n\n",
     ifelse(all(x$CI[1] == x$CI), "", "s"),
@@ -15,7 +16,7 @@ print.rope <- function(x, digits = 2, ...) {
   # why we did this, so I'll comment a bit...
 
   # These are the base columns we want to print
-  cols <- c("Parameter", "ROPE_Percentage", "Component", "Group")
+  cols <- c("Parameter", "ROPE_Percentage", "Effects", "Component")
 
   # In case we have ropes for different CIs, we also want this information
   # So we first check if values in the CI column differ, and if so, we also
@@ -52,4 +53,5 @@ print.rope <- function(x, digits = 2, ...) {
       cat("\n")
     }
   }
+  invisible(orig_x)
 }
