@@ -22,12 +22,13 @@
 #' @keywords internal
 .is_empty_object <- function(x) {
   if (is.list(x)) {
-    x <- tryCatch({
-      .compact_list(x)
-    },
-    error = function(x) {
-      x
-    }
+    x <- tryCatch(
+      {
+        .compact_list(x)
+      },
+      error = function(x) {
+        x
+      }
     )
   }
   # this is an ugly fix because of ugly tibbles
@@ -151,3 +152,36 @@
   x <- merge(x, y, by = by, all = all)
   .remove_column(x[order(x$.rowid), ], ".rowid")
 }
+
+
+
+# returns the row-indices for grouped data frames
+#' @keywords internal
+.group_indices <- function(x) {
+  # dplyr < 0.8.0 returns attribute "indices"
+  grps <- attr(x, "groups", exact = TRUE)
+
+  # dplyr < 0.8.0?
+  if (is.null(grps)) {
+    attr(x, "indices", exact = TRUE)
+  } else {
+    grps[[".rows"]]
+  }
+}
+
+
+
+# returns the variables that were used for grouping data frames (dplyr::group_var())
+#' @keywords internal
+.group_vars <- function(x) {
+  # dplyr < 0.8.0 returns attribute "indices"
+  grps <- attr(x, "groups", exact = TRUE)
+
+  # dplyr < 0.8.0?
+  if (is.null(grps)) {
+    ## TODO fix for dplyr < 0.8
+    attr(x, "vars", exact = TRUE)
+  } else {
+    setdiff(colnames(grps), ".rows")
+  }
+}
